@@ -107,7 +107,7 @@ INLINE void Socket_error( char *str, DWORD len, long num ) {
 	DWORD ret;
 #ifdef SC_DEBUG
 	int r1;
-	r1 = snprintf( str, len, "(%d) ", num );
+	r1 = _snprintf( str, len, "(%d) ", num );
 	len -= r1;
 	s1 = &str[r1];
 #else
